==> metview_5.13.1.orig.tar.xz: metview-5.13.1/mir/src/mir/action/plan/SimpleExecutor.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#pragma once

#include <iosfwd>

#include "mir/action/plan/Executor.h"


namespace mir {
namespace action {


class SimpleExecutor : public Executor {
public:
    // -- Exceptions
    // None

    // -- Constructors

    SimpleExecutor(const std::string& name);
    SimpleExecutor(const SimpleExecutor&) = delete;

    // -- Destructor
    // None

    // -- Convertors
    // None

    // -- Operators

    SimpleExecutor& operator=(const SimpleExecutor&) = delete;

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

protected:
    // -- Members
    // None

    // -- Methods

    void print(std::ostream&) const override;

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods
    // None

    // -- Overridden methods
    //
    void execute(context::Context&, const ActionNode&) const override;
    void wait() const override;
    void parametrisation(const param::MIRParametrisation&) override;

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace action
}  // namespace mir

==> metview_5.23.1.orig.tar.xz: metview-5.23.1/mir/src/mir/action/plan/SimpleExecutor.h <==
/*
 * (C) Copyright 1996- ECMWF.
 *
 * This software is licensed under the terms of the Apache Licence Version 2.0
 * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 *
 * In applying this licence, ECMWF does not waive the privileges and immunities
 * granted to it by virtue of its status as an intergovernmental organisation nor
 * does it submit to any jurisdiction.
 */


#pragma once

#include <iosfwd>

#include "mir/action/plan/Executor.h"


namespace mir::action {


class SimpleExecutor : public Executor {
public:
    // -- Exceptions
    // None

    // -- Constructors

    SimpleExecutor(const std::string& name);
    SimpleExecutor(const SimpleExecutor&) = delete;

    // -- Destructor
    // None

    // -- Convertors
    // None

    // -- Operators

    SimpleExecutor& operator=(const SimpleExecutor&) = delete;

    // -- Methods
    // None

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

protected:
    // -- Members
    // None

    // -- Methods

    void print(std::ostream&) const override;

    // -- Overridden methods
    // None

    // -- Class members
    // None

    // -- Class methods
    // None

private:
    // -- Members
    // None

    // -- Methods
    // None

    // -- Overridden methods
    //
    void execute(context::Context&, const ActionNode&) const override;
    void wait() const override;
    void parametrisation(const param::MIRParametrisation&) override;

    // -- Class members
    // None

    // -- Class methods
    // None

    // -- Friends
    // None
};


}  // namespace mir::action
